==> jc-1.4.0.tar.gz: javax/print/DocFlavor__24CHAR__5fARRAY.h <==
// public class javax.print.DocFlavor$CHAR_ARRAY

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class 43d97ef88e1ba720 javax_print_DocFlavor__24CHAR__5fARRAY

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_
#define _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$object;

typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct {
	struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	*TEXT__5fHTML;
	struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	*TEXT__5fPLAIN;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24CHAR__5fARRAY$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_print_DocFlavor__24CHAR__5fARRAY$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods	javax_print_DocFlavor__24CHAR__5fARRAY;
};

// Vtype
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs {
    _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs	javax_print_DocFlavor__24CHAR__5fARRAY;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs	javax_print_DocFlavor__24CHAR__5fARRAY;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object {
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype	*vtype;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype _jc_javax_print_DocFlavor__24CHAR__5fARRAY$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24CHAR__5fARRAY, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24CHAR__5fARRAY$class_object;

#endif	/* _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_ */

==> jc-1.4.6.tar.gz: javax/print/DocFlavor__24CHAR__5fARRAY.h <==
// public class javax.print.DocFlavor$CHAR_ARRAY

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class 43d97ef88e1ba720 javax_print_DocFlavor__24CHAR__5fARRAY

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_
#define _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$object;

typedef struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable;
typedef const struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct {
	struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	*TEXT__5fHTML;
	struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object	*TEXT__5fPLAIN;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24CHAR__5fARRAY$fields_struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24CHAR__5fARRAY$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_print_DocFlavor__24CHAR__5fARRAY$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vmethods	javax_print_DocFlavor__24CHAR__5fARRAY;
};

// Vtype
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs {
    _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_refs	javax_print_DocFlavor__24CHAR__5fARRAY;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24CHAR__5fARRAY$sub_nonrefs	javax_print_DocFlavor__24CHAR__5fARRAY;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24CHAR__5fARRAY$object {
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype	*vtype;
	_jc_javax_print_DocFlavor__24CHAR__5fARRAY$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24CHAR__5fARRAY$vtype _jc_javax_print_DocFlavor__24CHAR__5fARRAY$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24CHAR__5fARRAY, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24CHAR__5fARRAY$class_object;

#endif	/* _JC_javax_print_DocFlavor__24CHAR__5fARRAY_H_ */
